gchecky.model.tax_area_t

Package gchecky :: Module model :: Class tax_area_t |
[hide private]
[frames] | no frames]

# Class tax_area_t

source code

    object --+
             |
     gxml.Node --+
                 |
                tax_area_t

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `__neq__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| world_area = `PresentOrNot:PATH(world-area):OPT:EMPTY`
| postal_area = `Node:PATH(postal-area):OPT:{ postal_area_t }`
| us_state = `String:PATH(us-state-area/state):OPT:EMPTY`
| us_zip_pattern = `String:PATH(us-zip-area/zip-pattern):OPT:EMPTY`
| us_country_area = `String:PATH(us-country-area/country-area):OP`...``
| _fields = ``{``'``postal_area``'``:` Node:PATH(postal-area):OPT:{ postal_`...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### us_country_area Value:
      String:PATH(us-country-area/country-area):OPT:EMPTY:VALS("CONTINENTAL_
      48","FULL_50_STATES","ALL")

  ### _fields list of meta-Fields of this class. Value:
      {'postal_area': Node:PATH(postal-area):OPT:{ postal_area_t },
       'us_country_area': String:PATH(us-country-area/country-area):OPT:EMPT
      Y:VALS("CONTINENTAL_48","FULL_50_STATES","ALL"),
       'us_state': String:PATH(us-state-area/state):OPT:EMPTY,
       'us_zip_pattern': String:PATH(us-zip-area/zip-pattern):OPT:EMPTY,
       'world_area': PresentOrNot:PATH(world-area):OPT:EMPTY}